@@ -147,8 +147,9 @@ static uint16_t ext_fw_info_device[][2] = {
 	{0xc738, 0xc73b},	/* Switch-X */
 	{0xcb20, 0xcb20},	/* Switch-IB */
 	{0xcf08, 0xcf08},	/* Switch-IB2 */
+	{0xd2f0, 0xd2f0},	/* Quantum */
 	{0x01b3, 0x01b3},	/* IS-4 */
-	{0x1003, 0x1017},	/* Connect-X */
+	{0x1003, 0x101b},	/* Connect-X */
 	{0x1b02, 0x1b02},	/* Bull SwitchX */
 	{0x1b50, 0x1b50},	/* Bull SwitchX */
 	{0x1ba0, 0x1ba0},	/* Bull SwitchIB */
